@@ -24,6 +24,7 @@
 #include <sigc++/adaptors/adaptor_trait.h>
 #include <sigc++/functors/slot_base.h>
 #include <functional>
+
 #include <memory>
 
 namespace sigc
@@ -150,9 +151,7 @@ struct slot_call
   static T_return call_it(slot_rep* rep, type_trait_take_t<T_arg>... a_)
   {
     auto typed_rep = static_cast<typed_slot_rep<T_functor>*>(rep);
-    return (*typed_rep->functor_)
-      .template operator()<type_trait_take_t<T_arg>...>(
-        std::forward<type_trait_take_t<T_arg>>(a_)...);
+    return (*typed_rep->functor_).template operator()<type_trait_take_t<T_arg>...>(a_...);
   }
 
   /** Forms a function pointer from call_it().
@@ -221,7 +220,7 @@ public:
     {
       return std::invoke(sigc::internal::function_pointer_cast<call_type>(slot_base::rep_->call_),
         slot_base::rep_,
-        std::forward<type_trait_take_t<T_arg>>(a)...);
+        a...);
     }
 
     return T_return();
@@ -229,12 +228,6 @@ public:
 
   inline slot() = default;
 
-  // If you're tempted to add
-  //   template<typename T_functor,
-  //     std::enable_if_t<std::is_invocable_r_v<T_return, T_functor, T_arg...>, int> = 0>
-  // to the constructor, see https://github.com/libsigcplusplus/libsigcplusplus/issues/79
-  // It doesn't work well when sigc::slot is combined with sigc::hide().
-
   /** Constructs a slot from an arbitrary functor.
    * @param func The desired functor the new slot should be assigned to.
    */
