@@ -109,13 +109,13 @@ struct SIGC_API signal_impl : public std::enable_shared_from_this<signal_impl>
    */
   void block(bool should_block = true) noexcept;
 
-  /** Adds a slot at the end of the list of slots.
+  /** Adds a slot at the bottom of the list of slots.
    * @param slot_ The slot to add to the list of slots.
    * @return An iterator pointing to the new slot in the list.
    */
   iterator_type connect(const slot_base& slot_);
 
-  /** Adds a slot at the end of the list of slots.
+  /** Adds a slot at the bottom of the list of slots.
    * @param slot_ The slot to add to the list of slots.
    * @return An iterator pointing to the new slot in the list.
    *
@@ -123,22 +123,6 @@ struct SIGC_API signal_impl : public std::enable_shared_from_this<signal_impl>
    */
   iterator_type connect(slot_base&& slot_);
 
-  /** Adds a slot at the beginning of the list of slots.
-   * @param slot_ The slot to add to the list of slots.
-   * @return An iterator pointing to the new slot in the list.
-   *
-   * @newin{3,6}
-   */
-  iterator_type connect_first(const slot_base& slot_);
-
-  /** Adds a slot at the beginning of the list of slots.
-   * @param slot_ The slot to add to the list of slots.
-   * @return An iterator pointing to the new slot in the list.
-   *
-   * @newin{3,6}
-   */
-  iterator_type connect_first(slot_base&& slot_);
-
   /** Adds a slot at the given position into the list of slots.
    * @param i An iterator indicating the position where @p slot_ should be inserted.
    * @param slot_ The slot to add to the list of slots.
@@ -235,9 +219,8 @@ protected:
 } /* namespace internal */
 
 /** @defgroup signal Signals
- * Use @ref sigc::signal_with_accumulator::connect() "sigc::signal::connect()"
- * or @ref sigc::signal_with_accumulator::connect_first() "sigc::signal::connect_first()"
- * with sigc::mem_fun() and sigc::ptr_fun() to connect a method or function with a signal.
+ * Use sigc::signal::connect() with sigc::mem_fun() and sigc::ptr_fun() to connect a method or
+ * function with a signal.
  *
  * @code
  * signal_clicked.connect( sigc::mem_fun(*this, &MyWindow::on_clicked) );
@@ -249,9 +232,8 @@ protected:
  * If the type of your object inherits from sigc::trackable the method is disconnected
  * automatically when your object is destroyed.
  *
- * When signals are copied they share the underlying information, so you can have
- * a protected/private @ref sigc::signal<T_return(T_arg...)> "sigc::signal"
- * member and a public accessor method.
+ * When signals are copied they share the underlying information,
+ * so you can have a protected/private sigc::signal member and a public accessor method.
  * A sigc::signal is a kind of reference-counting pointer. It's similar to
  * std::shared_ptr<>, although sigc::signal is restricted to holding a pointer to
  * a sigc::internal::signal_impl object that contains the implementation of the signal.
@@ -277,31 +259,21 @@ protected:
  * if the given functor or closure cannot be invoked with the
  * parameter list of the signal to connect to.
  *
- * Almost any functor with the correct signature can be converted to
- * a @ref sigc::slot<T_return(T_arg...)> "sigc::slot"
- * and connected to a signal. See @ref slot "Slots" and
- * @ref sigc::signal_with_accumulator::connect() "sigc::signal::connect()".
+ * Almost any functor with the correct signature can be converted to a sigc::slot
+ * and connected to a signal. See @ref slot "Slots" and sigc::signal::connect().
  */
 
-// TODO: When we can break ABI, let signal_base derive from trackable again,
-// as in sigc++2. Otherwise the slot returned from signal::make_slot()
-// is not automatically disconnected when the signal is deleted.
-// And delete trackable_signal_with_accumulator and trackable_signal.
-// https://github.com/libsigcplusplus/libsigcplusplus/issues/80
-
-/** Base class for the @ref sigc::signal<T_return(T_arg...)> "sigc::signal" template.
- * %signal_base integrates most of the interface of the derived
- * @ref sigc::signal<T_return(T_arg...)> "sigc::signal" template.
- * The implementation, however, resides in sigc::internal::signal_impl.
- * A sigc::internal::signal_impl object is dynamically allocated from %signal_base
+/** Base class for the sigc::signal# templates.
+ * signal_base integrates most of the interface of the derived sigc::signal#
+ * templates. The implementation, however, resides in sigc::internal::signal_impl.
+ * A sigc::internal::signal_impl object is dynamically allocated from signal_base
  * when first connecting a slot to the signal. This ensures that empty signals
  * don't waste memory.
  *
- * sigc::internal::signal_impl is reference-counted.
- * When a @ref sigc::signal<T_return(T_arg...)> "sigc::signal" object
+ * sigc::internal::signal_impl is reference-counted. When a sigc::signal# object
  * is copied, the reference count of its sigc::internal::signal_impl object is
- * incremented. Both @ref sigc::signal<T_return(T_arg...)> "sigc::signal" objects
- * then refer to the same sigc::internal::signal_impl object.
+ * incremented. Both sigc::signal# objects then refer to the same
+ * sigc::internal::signal_impl object.
  *
  * @ingroup signal
  */
@@ -364,7 +336,7 @@ protected:
   using iterator_type = internal::signal_impl::iterator_type;
 
   /** Adds a slot at the end of the list of slots.
-   * With %connect(), slots can also be added during signal emission.
+   * With connect(), slots can also be added during signal emission.
    * In this case, they won't be executed until the next emission occurs.
    * @param slot_ The slot to add to the list of slots.
    * @return An iterator pointing to the new slot in the list.
@@ -372,7 +344,7 @@ protected:
   iterator_type connect(const slot_base& slot_);
 
   /** Adds a slot at the end of the list of slots.
-   * With %connect(), slots can also be added during signal emission.
+   * With connect(), slots can also be added during signal emission.
    * In this case, they won't be executed until the next emission occurs.
    * @param slot_ The slot to add to the list of slots.
    * @return An iterator pointing to the new slot in the list.
@@ -381,26 +353,6 @@ protected:
    */
   iterator_type connect(slot_base&& slot_);
 
-  /** Adds a slot at the beginning of the list of slots.
-   * With %connect_first(), slots can also be added during signal emission.
-   * In this case, they won't be executed until the next emission occurs.
-   * @param slot_ The slot to add to the list of slots.
-   * @return An iterator pointing to the new slot in the list.
-   *
-   * @newin{3,6}
-   */
-  iterator_type connect_first(const slot_base& slot_);
-
-  /** Adds a slot at the beginning of the list of slots.
-   * With %connect_fist(), slots can also be added during signal emission.
-   * In this case, they won't be executed until the next emission occurs.
-   * @param slot_ The slot to add to the list of slots.
-   * @return An iterator pointing to the new slot in the list.
-   *
-   * @newin{3,6}
-   */
-  iterator_type connect_first(slot_base&& slot_);
-
   /** Adds a slot at the given position into the list of slots.
    * Note that this function does not work during signal emission!
    * @param i An iterator indicating the position where @e slot_ should be inserted.
