@@ -16,8 +16,7 @@ std::ostringstream result_stream;
 
 struct arithmetic_mean_accumulator
 {
-  using result_type = double;
-  template <typename T_iterator>
+  template<typename T_iterator>
   double operator()(T_iterator first, T_iterator last) const
   {
     double value_ = 0;
@@ -28,14 +27,13 @@ struct arithmetic_mean_accumulator
   }
 };
 
-template <typename Ret>
+template<typename Ret>
 struct vector_accumulator
 {
-  using result_type = std::vector<Ret>;
-  template <typename T_iterator>
-  result_type operator()(T_iterator first, T_iterator last) const
+  template<typename T_iterator>
+  std::vector<Ret> operator()(T_iterator first, T_iterator last) const
   {
-    result_type vec;
+    std::vector<Ret> vec;
     for (; first != last; ++first)
       vec.push_back(*first);
     return vec;
