@@ -14,8 +14,6 @@ class Base : virtual public sigc::trackable
 public:
   Base() {}
 
-  Base(const Base& src) = default;
-  Base& operator=(const Base& src) = default;
   Base(Base&& src) = delete;
   Base& operator=(Base&& src) = delete;
 };
@@ -49,11 +47,11 @@ main(int argc, char* argv[])
   handler();
   util->check_result(result_stream, "method()");
 
-  sigc::slot<void()> param = sigc::bind(sigc::slot<void(Derived&)>(), std::ref(*instance));
+  auto param = sigc::bind(sigc::slot<void(Derived&)>(), std::ref(*instance));
   param();
   util->check_result(result_stream, "");
 
-  sigc::slot<Derived()> ret = sigc::bind_return(sigc::slot<void()>(), std::ref(*instance));
+  auto ret = sigc::bind_return(sigc::slot<void()>(), std::ref(*instance));
   ret();
   util->check_result(result_stream, "");
 
