@@ -8,6 +8,7 @@
 import os
 import sys
 import subprocess
+from pathlib import Path
 import shutil
 
 subcommand = sys.argv[1]
@@ -19,21 +20,9 @@ def html():
   input_xml_file = sys.argv[2]
   output_html_dir = sys.argv[3]
 
-  # Set the use.id.as.filename param so that we don't use the chapter / section
-  # number as the filename, otherwise the url will change every time anything is
-  # re-ordered or inserted in the documentation.
   # For a list of available parameters, see http://docbook.sourceforge.net/release/xsl/current/doc/html/
-  xslt_params = [
-    '--param', 'toc.section.depth', '1',
-    '--stringparam', 'chunker.output.indent', 'yes',
-    '--stringparam', 'chunker.output.encoding', 'UTF-8',
-    '--stringparam', 'toc.list.type', 'ul',
-    '--param', 'use.id.as.filename', '1',
-  ]
+  xslt_params = []
 
-  # The recommended stylesheet for DocBook V5.0 is .../xsl-ns/...
-  # It's not used here because the docbook-xsl-ns package is not available
-  # when building with gnome-build-meta.
   xslt_stylesheet = 'http://docbook.sourceforge.net/release/xsl/current/html/chunk.xsl'
 
   # Remove old files and create the destination directory.
@@ -58,8 +47,6 @@ def html():
   return result.returncode
 
 def xmllint():
-  from pathlib import Path
-
   #  argv[2]       argv[3]          argv[4]
   # <validate> <input_xml_file> <stamp_file_path>
 
@@ -67,15 +54,6 @@ def xmllint():
   input_xml_file = sys.argv[3]
   stamp_file_path = sys.argv[4]
 
-  relax_ng_schema = 'http://docbook.org/xml/5.0/rng/docbook.rng'
-  # schematron_schema = 'http://docbook.org/xml/5.0/sch/docbook.sch'
-
-  # Validation against the Schematron schema does not work on Ubuntu 21.04:
-  # file:///usr/share/xml/docbook/schema/schematron/5.0/docbook.sch:6: element rule:
-  #   Schemas parser error : Failed to compile context expression db:firstterm[@linkend]
-  # .....
-  # Schematron schema http://docbook.org/xml/5.0/sch/docbook.sch failed to compile
-
   cmd = [
     'xmllint',
     '--noout',
@@ -83,10 +61,7 @@ def xmllint():
     '--xinclude',
   ]
   if validate == 'true':
-    cmd += [
-      '--relaxng', relax_ng_schema,
-      #'--schematron', schematron_schema,
-    ]
+    cmd += ['--postvalid']
   cmd += [input_xml_file]
   result = subprocess.run(cmd)
   if result.returncode:
@@ -95,9 +70,6 @@ def xmllint():
   Path(stamp_file_path).touch(exist_ok=True)
   return 0
 
-# dblatex and xsltproc+fop generate a PDF file.
-# docbook2pdf can generate PDF files from DocBook4 files, but not from DocBook5 files.
-# xsltproc+xmlroff (version 0.6.3) does not seem to work acceptably.
 def dblatex():
   #      argv[2]         argv[3]
   # <input_xml_file> <output_pdf_file>
@@ -108,51 +80,40 @@ def dblatex():
 
   # For a list of available parameters, see http://dblatex.sourceforge.net/doc/manual/
   dblatex_params = [
-    '-P', 'toc.section.depth=1',
+    '-P', 'toc.section.depth=2',
     '-P', 'paper.type=a4paper',
-    '-P', 'doc.collab.show=1',
-    '-P', 'latex.output.revhistory=0',
   ]
 
   cmd = [
     'dblatex',
   ] + dblatex_params + [
     '-o', output_pdf_file,
-    '--pdf',
-    input_xml_file,
+    '--pdf', input_xml_file,
   ]
   return subprocess.run(cmd).returncode
 
-def fop():
+def docbook2pdf():
   #      argv[2]         argv[3]
   # <input_xml_file> <output_pdf_file>
-  # Create a PDF file, using fop.
+  # Create a PDF file, using docbook2pdf.
 
   input_xml_file = sys.argv[2]
   output_pdf_file = sys.argv[3]
 
-  fo_file = os.path.splitext(output_pdf_file)[0] + '.fo'
+  output_dir = os.path.dirname(output_pdf_file)
+  if not output_dir:
+    output_dir = '.'
+  output_basename = os.path.basename(output_pdf_file)
+  if output_basename.endswith('.pdf'):
+    output_basename = output_basename[:-4]
+  xml_file = os.path.join(output_dir, output_basename + '.xml')
 
-  # For a list of available parameters, see http://docbook.sourceforge.net/release/xsl/current/doc/fo/
-  # For a list of available paper types, see the description of the page.width.portrait parameter.
-  xslt_params = [
-    '--param', 'toc.section.depth', '1',
-    '--stringparam', 'fop1.extensions', '1',
-    '--stringparam', 'page.orientation', 'portrait',
-    '--stringparam', 'paper.type', 'A4',
-  ]
-
-  xslt_stylesheet = 'http://docbook.sourceforge.net/release/xsl/current/fo/docbook.xsl'
-
-  # Generate a .fo (formatting object) file.
-  # fop can take an xslt stylesheet parameter, but it can only read local files.
-  # xsltproc is necessary if you want to read the stylesheet from the internet.
+  # We need to produce an XML file with all of the XIncludes done.
   cmd = [
-    'xsltproc',
-  ] + xslt_params + [
-    '-o', fo_file,
+    'xmllint',
     '--xinclude',
-    xslt_stylesheet,
+    '--postvalid',
+    '--output', xml_file,
     input_xml_file,
   ]
   result = subprocess.run(cmd)
@@ -160,9 +121,9 @@ def fop():
     return result.returncode
 
   cmd = [
-    'fop',
-    '-fo', fo_file,
-    '-pdf', output_pdf_file,
+    'docbook2pdf',
+    '--output', output_dir,
+    xml_file,
   ]
   return subprocess.run(cmd).returncode
 
@@ -207,8 +168,8 @@ if subcommand == 'xmllint':
   sys.exit(xmllint())
 if subcommand == 'dblatex':
   sys.exit(dblatex())
-if subcommand == 'fop':
-  sys.exit(fop())
+if subcommand == 'docbook2pdf':
+  sys.exit(docbook2pdf())
 if subcommand == 'dist_doc':
   sys.exit(dist_doc())
 print(sys.argv[0], ': illegal subcommand,', subcommand)
